/*
 *
 * CLEX File Manager
 *
 * Copyright (C) 1997-2000 Tempest s.r.o. http://www.tempest.sk
 * Copyright (C) 2001-2002 Vlado Potisk <vlado_potisk@clex.sk>
 *
 * CLEX is free software without warranty of any kind; see the
 * GNU General Public License as set out in the "COPYING" document
 * which accompanies the CLEX File Manager package.
 *
 * CLEX can be downloaded from http://www.clex.sk
 *
 */

#include <autoconf.h>

#include <sys/types.h>
#include <stdio.h>
#ifdef MAJOR_IN_MKDEV
# include <sys/mkdev.h>
#endif
#ifdef MAJOR_IN_SYSMACROS
# include <sys/sysmacros.h>
#endif
#include <stdlib.h>

int
main(int argc, char *argv[])
{
	size_t i, minorlen, majorlen;
	unsigned int max;
	dev_t all_ones;

	if (argc != 3) {
		fputs("This utility is required to build CLEX from sources.\n"
		  "It is not intended to be invoked from the command line.\n",
		  stderr);
		exit(1);
	}

	puts("/* generated by mkheader */");

	/* I. get installation directories from make */
	printf("#define CONFIG_FILE\t\"%s/clexrc\"\n",argv[1]);
	printf("#define HELP_FILE\t\"%s/english.hlp\"\n",argv[2]);

	/* II. determine device minor and major number sizes */
	for (i = 0; i < sizeof(all_ones); i++)
		((char *)&all_ones)[i] = (char)0x7F;
   		/* was 0xFF, that's why the name 'all_ones' */

	for (majorlen = 0, max = major(all_ones); max > 0; max /= 0x100)
		majorlen++;	/* in bytes */
	majorlen = 1 + (241 * majorlen) / 100;	/* in decimal digits */
	/* log 256 at base 10 is approx. 241/100 */

	for (minorlen = 0, max = minor(all_ones); max > 0; max /= 0x100)
		minorlen += 2;	/* in hex digits */

	printf("#define DEV_FORMAT\t\"%%%dd:0x%%0%dX\"\n",
	  majorlen,minorlen);
	printf("#define FE_DEV_STR\t%u\n",majorlen + minorlen + 4);

	return 0;
}
