/*
 *
 * CLEX File Manager
 *
 * Copyright (C) 1997-2000 Tempest s.r.o. http://www.tempest.sk
 * Copyright (C) 2001-2002 Vlado Potisk <vlado_potisk@clex.sk>
 *
 * CLEX is free software without warranty of any kind; see the
 * GNU General Public License as set out in the "COPYING" document
 * which accompanies the CLEX File Manager package.
 *
 * CLEX can be downloaded from http://www.clex.sk
 *
 */

#include <autoconf.h>

#include <sys/types.h>			/* clex.h */
#include <ctype.h>				/* isdigit() */
#include <stdarg.h>				/* va_list() */
#include <stdlib.h>				/* malloc() */
#include <string.h>				/* strlen() */

#include "clex.h"
#include "util.h"

#include "ustring.h"			/* us_copy() */
#include "err.h"				/* err_exit() */

/* variables used in pathname_xxx() functions */
static USTRING sf_buff = { 0,0 };
static size_t sf_dirlen;

/* get rid of directory part in 'pathname' */
const char
*base_name(const char *pathname)
{
	const char *base, *pch;
	char ch;

	for (pch = base = pathname; (ch = *pch++) != '\0'; )
		if (ch == '/')
			base = pch;
	return base;
}

static void
alloc_fail(size_t size)
{
	err_exit("Memory exhausted, could not allocate %lu bytes",
	  (unsigned long)size);
	/* NOTREACHED */
}

/* malloc with error checking */
void *
emalloc(size_t size)
{
	void *m;

	if ((m = malloc(size)) == 0)
		alloc_fail(size);
	return m;
}

/* realloc with error checking */
void *
erealloc(void *ptr, size_t size)
{
	void *m;

	/* not sure if really all realloc()s can handle this case */
	if (ptr == 0)
		return emalloc(size);

	if ((m = realloc(ptr,size)) == 0)
		alloc_fail(size);
	return m;
}

/* strdup with error checking */
char *
estrdup(const char *str)
{
	char *m;

	m = emalloc(strlen(str) + 1);
	strcpy(m,str);
	return m;
}

/* set the directory name for pathname_join() */
void
pathname_set_directory(const char *dir)
{
	sf_dirlen = strlen(dir);
	us_resize(&sf_buff,sf_dirlen + 24);
	/* 24 extra bytes = slash + some initial room for filename + null */
	strcpy(USTR(sf_buff),dir);
	if (USTR(sf_buff)[sf_dirlen - 1] != '/')
		USTR(sf_buff)[sf_dirlen++] = '/';
		/* the string is now not null terminated, that's ok */
}

/*
 * join the filename 'file' with the directory set by
 * pathname_set_directory() above
 * returned data is overwritten by subsequent calls
 */
char *
pathname_join(const char *file)
{
	us_resize(&sf_buff,sf_dirlen + strlen(file) + 1);
	strcpy(USTR(sf_buff) + sf_dirlen,file);
	return USTR(sf_buff);
}
